# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('dbmail', '0006_auto_20150708_0714'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='mailsubscription',
            options={'verbose_name': 'Mail Subscription', 'verbose_name_plural': 'Mail Subscriptions'},
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='address',
            field=models.CharField(help_text='Must be phone number/email/token', unique=True, max_length=60, verbose_name='Address'),
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='backend',
            field=models.CharField(default=b'dbmail.backends.mail', max_length=50, verbose_name='Backend', choices=[(b'dbmail.backends.mail', 'MailBox'), (b'dbmail.backends.push', 'Push'), (b'dbmail.backends.sms', 'SMS'), (b'dbmail.backends.tts', 'TTS')]),
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='defer_at_allowed_hours',
            field=models.BooleanField(default=False, verbose_name='Defer at allowed hours'),
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='end_hour',
            field=models.CharField(default=b'23:59', max_length=5, verbose_name='End hour'),
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='is_checked',
            field=models.BooleanField(default=False, db_index=True, verbose_name='Is checked'),
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='is_enabled',
            field=models.BooleanField(default=True, db_index=True, verbose_name='Is enabled'),
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='start_hour',
            field=models.CharField(default=b'00:00', max_length=5, verbose_name='Start hour'),
        ),
    ]



# -*- encoding: utf-8 -*-

from httplib import HTTPSConnection
from json import dumps, loads

from django.conf import settings

from dbmail import get_version


class ParseComError(Exception):
    pass


def send(device_id, description, **kwargs):
    """
    Site: http://parse.com
    API: https://www.parse.com/docs/push_guide#scheduled/REST
    Desc: Best app for system administrators
    """
    headers = {
        "X-Parse-Application-Id": settings.PARSE_APP_ID,
        "X-Parse-REST-API-Key": settings.PARSE_API_KEY,
        "User-Agent": "DBMail/%s" % get_version(),
        "Content-type": "application/json",
    }

    data = {
        "where": {
            "user_id": device_id,
        },
        "data": {
            "alert": description,
            "title": kwargs.pop("event")
        }
    }

    _data = kwargs.pop('data', None)
    if _data is not None:
        data.update(_data)

    http = HTTPSConnection(kwargs.pop("api_url", "api.parse.com"))
    http.request(
        "POST", "/1/push",
        headers=headers,
        body=dumps(data))
    response = http.getresponse()

    if response.status != 200:
        raise ParseComError(response.reason)

    body = loads(response.read())
    if body['error']:
        raise ParseComError(body['error'])
    return True



# -*- coding: utf-8 -*-

from urllib import urlopen, urlencode
from json import loads

from django.conf import settings

from dbmail.providers.prowl.push import from_unicode


class NexmoSmsError(Exception):
    pass


def send(sms_to, sms_body, **kwargs):
    api_url = kwargs.pop('api_url', 'https://rest.nexmo.com/sms/json')
    params = {
        'api_key': settings.NEXMO_USERNAME,
        'api_secret': settings.NEXMO_PASSWORD,
        'from': kwargs.pop('sms_from', settings.NEXMO_FROM),
        'to': sms_to.replace('+', ''),
        'type': 'unicode',
        'lg': settings.NEXMO_LANG,
        'text': from_unicode(sms_body)
    }
    if kwargs:
        params.update(**kwargs)

    url = urlopen('%s?%s' % (api_url, urlencode(params)))
    messages = loads(url.read())

    response = messages.get('messages')
    if response and response[0].get('error-text'):
        raise NexmoSmsError(messages['messages'][0]['error-text'])
    elif 'status' in messages and messages.get('status') != '0':
        raise NexmoSmsError(messages.get('error-text'))
    return messages



# -*- encoding: utf-8 -*-

from django.conf import settings

from dbmail.defaults import SMS_PROVIDER, DEFAULT_SMS_FROM
from dbmail.backends.mail import Sender as SenderBase
from dbmail.utils import clean_html
from dbmail import import_module


class Sender(SenderBase):
    provider = SMS_PROVIDER
    default_from = DEFAULT_SMS_FROM

    def _get_from_email(self):
        if self._kwargs.get('from_email'):
            return self._kwargs.pop('from_email', None)
        elif not self._template.from_email:
            if self.default_from:
                return self.default_from
            else:
                return settings.DEFAULT_FROM_EMAIL.split('<')[0].strip()
        return self._template.from_email.email

    def _get_recipient_list(self, recipient):
        if not isinstance(recipient, list) and '+' not in recipient:
            return self._group_emails(recipient)
        return self._email_to_list(recipient)

    def _send(self):
        module = import_module(self._provider)
        message = clean_html(self._message)
        for phone in self._recipient_list:
            if self._from_email:
                module.send(
                    phone, message, sms_from=self._from_email, **self._kwargs)
            else:
                module.send(phone, message, **self._kwargs)


class SenderDebug(Sender):
    def _send(self):
        self.debug('Provider', self._provider or self.provider)
        self.debug('Message', clean_html(self._message))
        self.debug('Recipients', self._recipient_list)
        self.debug('Sms from', self._from_email)
        self.debug('Additional params', self._kwargs)



# -*- encoding: utf-8 -*-

import telepot
from django.conf import settings


def send(to, message, **kwargs):
    """
       SITE: https://github.com/nickoala/telepot
       TELEGRAM API: https://core.telegram.org/bots/api

       Installation:
       pip install 'telepot>=10.4'
   """

    available_kwargs_keys = [
        'parse_mode',
        'disable_web_page_preview',
        'disable_notification',
        'reply_to_message_id',
        'reply_markup'
    ]

    available_kwargs = {
        k: v for k, v in kwargs.iteritems() if k in available_kwargs_keys
    }

    bot = telepot.Bot(settings.TELEGRAM_BOT_TOKEN)
    return bot.sendMessage(to, message, **available_kwargs)



# -*- encoding: utf-8 -*-

from django.utils.html import strip_tags

from dbmail import import_module


def premailer_transform(text):
    try:
        from premailer import transform

        return transform(text)
    except Exception as err:
        print(err)
        return text


def get_ip(request):
    try:
        from ipware.ip import get_real_ip

        ip = get_real_ip(request)
        if ip is not None:
            return ip.strip()
    except ImportError:
        pass

    return request.META['REMOTE_ADDR'].split(',')[-1].strip()


def html2text(message):
    try:
        from html2text import html2text

        return html2text(message)
    except ImportError:
        return strip_tags(message)


def clean_html(message):
    from dbmail.defaults import MESSAGE_HTML2TEXT

    module = import_module(MESSAGE_HTML2TEXT)
    return module.html2text(message)



# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding field 'MailTemplate.context_note'
        db.add_column('dbmail_mailtemplate', 'context_note',
                      self.gf('django.db.models.fields.TextField')(null=True, blank=True),
                      keep_default=False)


    def backwards(self, orm):
        # Deleting field 'MailTemplate.context_note'
        db.delete_column('dbmail_mailtemplate', 'context_note')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'dbmail.mailcategory': {
            'Meta': {'object_name': 'MailCategory'},
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '25'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'})
        },
        'dbmail.mailgroup': {
            'Meta': {'object_name': 'MailGroup'},
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '50'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'})
        },
        'dbmail.mailgroupemail': {
            'Meta': {'object_name': 'MailGroupEmail'},
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75'}),
            'group': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['dbmail.MailGroup']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'dbmail.maillog': {
            'Meta': {'object_name': 'MailLog'},
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'error_message': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_sent': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'num_of_retries': ('django.db.models.fields.PositiveIntegerField', [], {'default': '1'}),
            'template': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['dbmail.MailTemplate']"}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'null': 'True', 'blank': 'True'})
        },
        'dbmail.maillogemail': {
            'Meta': {'object_name': 'MailLogEmail'},
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'log': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['dbmail.MailLog']"}),
            'mail_type': ('django.db.models.fields.CharField', [], {'max_length': '3'})
        },
        'dbmail.mailtemplate': {
            'Meta': {'object_name': 'MailTemplate'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['dbmail.MailCategory']", 'null': 'True', 'blank': 'True'}),
            'context_note': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_admin': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_html': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'message': ('django.db.models.fields.TextField', [], {}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'num_of_retries': ('django.db.models.fields.PositiveIntegerField', [], {'default': '1'}),
            'priority': ('django.db.models.fields.SmallIntegerField', [], {'default': '0'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '50'}),
            'subject': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['dbmail']


from django.core.management.base import BaseCommand
from django.core.management import call_command


class Command(BaseCommand):
    def handle(self, *args, **options):
        call_command('loaddata', 'mailgun_base_templates', app_label='dbmail')



# -*- encoding: utf-8 -*-

import hmac
from hashlib import sha256
from json import dumps
from urllib import urlencode
from urllib2 import urlopen, Request

from django.conf import settings


class CentrifugoError(Exception):
    pass


def send(channel, data, **kwargs):
    if type(data) not in (set, dict, list, tuple):
        kwargs['message'] = data

    data = dumps([{
        "method": "publish",
        "params": {
            "channel": channel,
            "data": kwargs,
        },
    }])
    sign = hmac.new(settings.CENTRIFUGO_TOKEN, data, sha256).hexdigest()
    payload = urlencode({'data': data, 'sign': sign})

    response = urlopen(
        Request(settings.CENTRIFUGO_API),
        payload,
        timeout=10
    )
    if response.code != 200:
        raise CentrifugoError(response.read())
    return True



# -*- encoding: utf-8 -*-

from json import loads
from urllib import urlencode
from urllib2 import urlopen, Request

from django.conf import settings


class PushAllError(Exception):
    pass


def send(ch, message, **kwargs):
    """
    Site: https://pushall.ru
    API: https://pushall.ru/blog/api
    Desc: App for notification to devices/browsers and messaging apps
    """
    params = {
        'type': kwargs.pop('req_type', 'self'),
        'key': settings.PUSHALL_API_KEYS[ch]['key'],
        'id': settings.PUSHALL_API_KEYS[ch]['id'],
        'title': kwargs.pop(
            "title", settings.PUSHALL_API_KEYS[ch].get('title') or ""),
        'text': message,
        'priority': kwargs.pop(
            "priority", settings.PUSHALL_API_KEYS[ch].get('priority') or "0"),
    }
    if kwargs:
        params.update(**kwargs)

    response = urlopen(
        Request('https://pushall.ru/api.php'),
        urlencode(params),
        timeout=10
    )

    if response.code != 200:
        raise PushAllError(response.read())

    json = loads(response.read())
    if json.get('error'):
        raise PushAllError(json.get('error'))

    return True



import re
import optparse

from django.core.management.base import BaseCommand

from dbmail.models import MailTemplate
from dbmail.defaults import BACKEND
from dbmail import db_sender


def send_test_msg(pk, email, user=None, **kwargs):
    template = MailTemplate.objects.get(pk=pk)
    slug = template.slug
    var_list = re.findall('\{\{\s?(\w+)\s?\}\}', template.message)
    context = {}
    for var in var_list:
        context[var] = '%s' % var.upper().replace('_', '-')
    return db_sender(slug, email, user, context, **kwargs)


class Command(BaseCommand):
    option_list = BaseCommand.option_list + (
        optparse.make_option('--email', dest='email', help='Recipients'),
        optparse.make_option('--pk', dest='pk', help='DBMail template id'),
        optparse.make_option('--without-celery', action='store_true',
                             default=False, dest='celery',
                             help='Send direct message'),
        optparse.make_option('--provider', dest='provider', help='Provider'),
        optparse.make_option(
            '--backend', dest='backend', help='Backend', default='mail'),
    )

    @staticmethod
    def get_kwargs(options):
        kwargs = {
            'use_celery': not options['celery'],
            'backend': BACKEND['mail']}
        if options['provider']:
            kwargs['provider'] = options['provider']
        if options['backend']:
            kwargs['backend'] = BACKEND[options['backend']]
        return kwargs

    def handle(self, *args, **options):
        send_test_msg(
            options['pk'], options['email'], **self.get_kwargs(options)
        )
        print("Done. Message was sent.")
